@@ -3,7 +3,7 @@ use Mojo::Base 'Mojolicious::Command';
 
 use S2::FW::Controller::Firewall;
 
-has description => 'Change everything to default mode';
+has description => 'Apply default mode unless skip reset is set';
 has usage       => "Usage: APPLICATION default\n";
 
 sub run {
