@@ -12,9 +12,8 @@ sub register {
 
             my $rows = dclone $c->config->{rows};
 
-            my $nf = decode_json qx(/usr/sbin/nft -j list table s2fw || echo '{"nftables":[{"map":{"name":"host_mode"}},{"set":{"name":"lambda_hosts"}}]}');
+            my $nf = decode_json qx(/usr/sbin/nft -j list table s2fw || echo '{"nftables":[{"map":{"name":"host_mode"}}]}');
             my $host_mode    = (grep { defined $_->{map} and $_->{map}->{name} eq 'host_mode' } @{$nf->{nftables}})[0]->{map}->{elem} // [];
-            my $lambda_hosts = (grep { defined $_->{set} and $_->{set}->{name} eq 'lambda_hosts' } @{$nf->{nftables}})[0]->{set}->{elem} // [];
 
             foreach my $row (@$rows) {
                 $row->{current_status} = [];
@@ -23,7 +22,6 @@ sub register {
                 push @{$row->{current_status}}, 'admin' if exists $mode->[1]->{accept};
                 push @{$row->{current_status}}, 'web' if exists $mode->[1]->{jump} and $mode->[1]->{jump}->{target} eq 'web';
                 push @{$row->{current_status}}, 'blocked' if exists $mode->[1]->{drop};
-                push @{$row->{current_status}}, (grep { $_ eq $row->{ip} } @{$lambda_hosts}) ? 'lambda' : 'tmobile';
             }
 
             return $rows;
@@ -33,13 +31,7 @@ sub register {
             my ($c, $row, $new_mode) = @_;
 
             my @cmd;
-            if ($new_mode eq 'lambda') {
-                push @cmd, "add element s2fw lambda_hosts { $row->{ip} }" if grep { /tmobile/i } @{$row->{current_status}};
-            }
-            elsif ($new_mode eq 'tmobile') {
-                push @cmd, "delete element s2fw lambda_hosts { $row->{ip} }" if grep { /lambda/i } @{$row->{current_status}};
-            }
-            elsif ($new_mode eq 'admin') {
+            if ($new_mode eq 'admin') {
                 push @cmd, "delete element s2fw host_mode { $row->{ip} }" unless grep { /unknown/i } @{$row->{current_status}};
                 push @cmd, "add element s2fw host_mode { $row->{ip} : accept }";
                 push @cmd, "add element s2fw port_to_ip { $row->{port_range}->[0]-$row->{port_range}->[1] : $row->{ip} }";
